use warnings;
use strict;

use Test::More;
use Test::Exception;
use Test::MockModule;

use POWER::Email;

plan tests => 11;


my $Mail;
my $m = new Test::MockModule('POWER::Email');
$m->mock('_send_mail', sub { $Mail = shift; return });

my $tmpl;


throws_ok { Email()                     }   qr/open:/;
throws_ok { Email(undef)                }   qr/open:/;
throws_ok { Email(q{})                  }   qr/open:/;


lives_ok  { Email('/dev/null')          }   'empty file';
is($Mail, q{},                              '  empty mail');


$tmpl = <<'EO_TMPL';
To: root@localhost

EO_TMPL
Email($tmpl);
is($Mail, $tmpl,                            'simple static template');
Email('t/tmpl/1.tmpl');
is($Mail, $tmpl,                            'simple static template in file');


$tmpl = <<'EO_TMPL';
To: @~email~@

EO_TMPL
Email($tmpl, {email=>'nobody@localhost'});
is($Mail, "To: nobody\@localhost\n\n",      'simple dynamic template');


Email('t/tmpl/1.tmpl', undef, {'t/tmpl/1.tmpl' => undef});
like($Mail, qr{MULTIPART/MIXED.*filename="1\.tmpl"}is,
                                            'attach file');


throws_ok { Email('t/tmpl/1.tmpl', undef, {'no_such' => undef})} qr/open:/;
Email('t/tmpl/1.tmpl', undef, {'no_such' => 'fake'});
like($Mail, qr{MULTIPART/MIXED.*filename="no_such"}is,
                                            'attach scalar');

